/*******************************************************************************
* File Name: toCPLD.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "toCPLD.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        toCPLD_PC =   (toCPLD_PC & \
                                (uint32)(~(uint32)(toCPLD_DRIVE_MODE_IND_MASK << (toCPLD_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (toCPLD_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: toCPLD_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void toCPLD_Write(uint8 value) 
{
    uint8 drVal = (uint8)(toCPLD_DR & (uint8)(~toCPLD_MASK));
    drVal = (drVal | ((uint8)(value << toCPLD_SHIFT) & toCPLD_MASK));
    toCPLD_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: toCPLD_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  toCPLD_DM_STRONG     Strong Drive 
*  toCPLD_DM_OD_HI      Open Drain, Drives High 
*  toCPLD_DM_OD_LO      Open Drain, Drives Low 
*  toCPLD_DM_RES_UP     Resistive Pull Up 
*  toCPLD_DM_RES_DWN    Resistive Pull Down 
*  toCPLD_DM_RES_UPDWN  Resistive Pull Up/Down 
*  toCPLD_DM_DIG_HIZ    High Impedance Digital 
*  toCPLD_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void toCPLD_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(toCPLD__0__SHIFT, mode);
	SetP4PinDriveMode(toCPLD__1__SHIFT, mode);
	SetP4PinDriveMode(toCPLD__2__SHIFT, mode);
	SetP4PinDriveMode(toCPLD__3__SHIFT, mode);
	SetP4PinDriveMode(toCPLD__4__SHIFT, mode);
}


/*******************************************************************************
* Function Name: toCPLD_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro toCPLD_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 toCPLD_Read(void) 
{
    return (uint8)((toCPLD_PS & toCPLD_MASK) >> toCPLD_SHIFT);
}


/*******************************************************************************
* Function Name: toCPLD_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 toCPLD_ReadDataReg(void) 
{
    return (uint8)((toCPLD_DR & toCPLD_MASK) >> toCPLD_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(toCPLD_INTSTAT) 

    /*******************************************************************************
    * Function Name: toCPLD_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 toCPLD_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(toCPLD_INTSTAT & toCPLD_MASK);
		toCPLD_INTSTAT = maskedStatus;
        return maskedStatus >> toCPLD_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
